==> lpmn_client_biz-2.1.2-py3-none-any.whl: lpmn_client_biz/connection.py <==
"""Connection class implementation."""
import os
from enum import Enum
from glob import glob

import requests
from pyaml_env import parse_config

USERNAME = 'USERNAME'
PASSWORD = 'PASSWORD'
CONFIG_REGX = 'config*.y*ml'
DOT_CLARIN = '.clarin'
ACCESS_TOKEN = 'access_token'
BASE_URL = 'BASE_URL'
API_TOKEN = 'API_TOKEN'


requests.packages.urllib3.disable_warnings(
    requests.packages.urllib3.exceptions.InsecureRequestWarning)


class IOType(Enum):
    """Enum type for input types."""

    TEXT = "text"
    FILE = "file"
    FILE_ID = "file_id"

    def __str__(self):
        """To string for IOType Enum."""
        return self.name.lower()

    def __repr__(self):
        """String representation for IOType Enum."""
        return str(self)

    @staticmethod
    def argparse(s):
        """Argument parsing for argparser type."""
        try:
            return IOType[s.upper()]
        except KeyError:
            return s


class Connection:
    """Implementation of Connection class."""

    BASE_API_URL = "https://services.clarin-pl.eu/api/v1"
    API_ENDPOINTS = {
        "login": "/oauth/login",
        "files": "/files/",
        "tasks": {"start": "/tasks/",
                  "run": "/tasks/run/",
                  "progress": "/tasks/",
                  "sent": "/tasks/sent/",
                  "status": "/tasks/users/",
                  "cancel": "/tasks/cancel/"}
    }

    def __init__(self, username='', password='',
                 baseurl='', config_file='', api_token='', x_token='',
                 x_token_header=False) -> None:
        """Configure connection authorization with api.

        :param username: e-science username
        :type username: str
        :param password: e-science user password
        :type password: str
        :param baseurl: base api url if different from default
        :type baseurl: str
        :param config_file: path of user config file with username and password
        :type config_file: str
        :param api_token: keycloak permanent user token
        :type api_token: str
        :param x_token: internal user x_token
        :type x_token: str
        :param x_token_header: if x-token  should be added to request header
        :type x_token_header: bool
        """
        if os.name == "nt":  # Windows
            base_dir = os.getenv('LOCALAPPDATA') if \
                os.getenv('LOCALAPPDATA') else os.getenv('APPDATA')
        else:
            base_dir = os.path.expanduser('~')

        if os.path.isfile(config_file):
            user_config = config_file
        else:
            config = Connection.__get_glob_config(CONFIG_REGX)
            if os.path.isfile(config):
                user_config = config
            else:
                user_config = Connection.__get_glob_config(
                    os.path.join(base_dir, DOT_CLARIN, CONFIG_REGX))

        self.x_token_header = x_token_header

        self.token = None
        self.api_token_header = False
        if x_token:
            self.token = x_token
        elif api_token:
            self.token = api_token
            self.api_token_header = True

        self.base_url = Connection.BASE_API_URL
        if baseurl:
            self.base_url = baseurl
        elif self.token is None and os.path.isfile(user_config):
            config = parse_config(user_config)
            if BASE_URL in config:
                self.base_url = config[BASE_URL]
            if self.token is None and API_TOKEN in config:
                self.token = config[API_TOKEN]
                self.api_token_header = True

        if self.token is None:
            if username and password:
                self.token, info = self.__get_api_token(username, password)
            elif os.path.isfile(user_config):
                self.token, info = self.__parse_config(user_config)
            else:
                info = "User credentials not provided, " \
                       "please add config file or use -u, -p " \
                       "parameters"  # pragma: no cover

            if self.token is None:
                raise Exception(f'Authorization Error, {info} '
                                f'API_URL: {self.base_url}')

    def __parse_config(self, config_file):
        config = parse_config(config_file)
        if USERNAME in config and PASSWORD in config:
            return self.__get_api_token(config[USERNAME],
                                        config[PASSWORD])
        else:
            return None, f'{USERNAME} or {PASSWORD} not present ' \
                         f'in config file on path {config_file}'

    def __get_api_token(self, username: str, password: str):
        try:
            r = requests.post(
                url=f"{self.base_url}{Connection.API_ENDPOINTS['login']}",
                json={
                    "username": username,
                    "password": password
                },
                verify=False
            )
            if r.status_code == 200:
                data = r.json()
                return data[ACCESS_TOKEN], 'OK'
            return None, 'Invalid credentials'
        except requests.ConnectTimeout:
            return None, 'Connection timeout'

    @staticmethod
    def __get_glob_config(path):
        config = glob(path)
        config = config[0] if len(config) > 0 else ''
        return config

    def headers(self):
        """Sets request header."""
        if self.x_token_header:
            return {"x-token": f"{self.token}"}
        elif self.api_token_header:
            return {"API-TOKEN": f"{self.token}"}
        else:
            return {"Authorization": f"Bearer {self.token}"}

==> lpmn_client_biz-2.1.3-py3-none-any.whl: lpmn_client_biz/connection.py <==
"""Connection class implementation."""
import os
from enum import Enum
from glob import glob

import requests
from pyaml_env import parse_config

USERNAME = 'USERNAME'
PASSWORD = 'PASSWORD'
CONFIG_REGX = 'config*.y*ml'
DOT_CLARIN = '.clarin'
ACCESS_TOKEN = 'access_token'
BASE_URL = 'BASE_URL'
API_TOKEN = 'API_TOKEN'


requests.packages.urllib3.disable_warnings(
    requests.packages.urllib3.exceptions.InsecureRequestWarning)


class IOType(Enum):
    """Enum type for input types."""

    TEXT = "text"
    FILE = "file"
    FILE_ID = "file_id"

    def __str__(self):
        """To string for IOType Enum."""
        return self.name.lower()

    def __repr__(self):
        """String representation for IOType Enum."""
        return str(self)

    @staticmethod
    def argparse(s):
        """Argument parsing for argparser type."""
        try:
            return IOType[s.upper()]
        except KeyError:
            return s


class Connection:
    """Implementation of Connection class."""

    BASE_API_URL = "https://services.clarin-pl.eu/api/v1"
    API_ENDPOINTS = {
        "login": "/oauth/login",
        "files": "/files/",
        "tasks": {"start": "/tasks/",
                  "run": "/tasks/run/",
                  "progress": "/tasks/",
                  "sent": "/tasks/sent/",
                  "status": "/tasks/users/",
                  "cancel": "/tasks/cancel/",
                  "llm_completions": "/tasks/llm/completions",
                  "llm_edits": "/tasks/llm/edits"
                  },
    }

    def __init__(self, username='', password='',
                 baseurl='', config_file='', api_token='', x_token='',
                 x_token_header=False) -> None:
        """Configure connection authorization with api.

        :param username: e-science username
        :type username: str
        :param password: e-science user password
        :type password: str
        :param baseurl: base api url if different from default
        :type baseurl: str
        :param config_file: path of user config file with username and password
        :type config_file: str
        :param api_token: keycloak permanent user token
        :type api_token: str
        :param x_token: internal user x_token
        :type x_token: str
        :param x_token_header: if x-token  should be added to request header
        :type x_token_header: bool
        """
        if os.name == "nt":  # Windows
            base_dir = os.getenv('LOCALAPPDATA') if \
                os.getenv('LOCALAPPDATA') else os.getenv('APPDATA')
        else:
            base_dir = os.path.expanduser('~')

        if os.path.isfile(config_file):
            user_config = config_file
        else:
            config = Connection.__get_glob_config(CONFIG_REGX)
            if os.path.isfile(config):
                user_config = config
            else:
                user_config = Connection.__get_glob_config(
                    os.path.join(base_dir, DOT_CLARIN, CONFIG_REGX))

        self.x_token_header = x_token_header

        self.token = None
        self.api_token_header = False
        if x_token:
            self.token = x_token
        elif api_token:
            self.token = api_token
            self.api_token_header = True

        self.base_url = Connection.BASE_API_URL
        if baseurl:
            self.base_url = baseurl
        elif self.token is None and os.path.isfile(user_config):
            config = parse_config(user_config)
            if BASE_URL in config:
                self.base_url = config[BASE_URL]
            if self.token is None and API_TOKEN in config:
                self.token = config[API_TOKEN]
                self.api_token_header = True

        if self.token is None:
            if username and password:
                self.token, info = self.__get_api_token(username, password)
            elif os.path.isfile(user_config):
                self.token, info = self.__parse_config(user_config)
            else:
                info = "User credentials not provided, " \
                       "please add config file or use -u, -p " \
                       "parameters"  # pragma: no cover

            if self.token is None:
                raise Exception(f'Authorization Error, {info} '
                                f'API_URL: {self.base_url}')

    def __parse_config(self, config_file):
        config = parse_config(config_file)
        if USERNAME in config and PASSWORD in config:
            return self.__get_api_token(config[USERNAME],
                                        config[PASSWORD])
        else:
            return None, f'{USERNAME} or {PASSWORD} not present ' \
                         f'in config file on path {config_file}'

    def __get_api_token(self, username: str, password: str):
        try:
            r = requests.post(
                url=f"{self.base_url}{Connection.API_ENDPOINTS['login']}",
                json={
                    "username": username,
                    "password": password
                },
                verify=False
            )
            if r.status_code == 200:
                data = r.json()
                return data[ACCESS_TOKEN], 'OK'
            return None, 'Invalid credentials'
        except requests.ConnectTimeout:
            return None, 'Connection timeout'

    @staticmethod
    def __get_glob_config(path):
        config = glob(path)
        config = config[0] if len(config) > 0 else ''
        return config

    def headers(self):
        """Sets request header."""
        if self.x_token_header:
            return {"x-token": f"{self.token}"}
        elif self.api_token_header:
            return {"API-TOKEN": f"{self.token}"}
        else:
            return {"Authorization": f"Bearer {self.token}"}
